@@ -41,6 +41,7 @@ use Data::Dumper;
 use App::Dochazka::REST::Model::Shared qw( cud );
 use DBI;
 
+use parent 'App::Dochazka::REST::dbh';
 
 
 =head1 NAME
@@ -52,11 +53,11 @@ App::Dochazka::REST::Model::Lock - lock data model
 
 =head1 VERSION
 
-Version 0.090
+Version 0.093
 
 =cut
 
-our $VERSION = '0.090';
+our $VERSION = '0.093';
 
 
 
@@ -188,7 +189,7 @@ whatever was there before.  Returns a status object.
 
 sub load_by_lid {
     my ( $self, $lid ) = @_;
-    my $dbh = $self->{dbh};
+    my $dbh = $self->dbh;
     my @attrs = ( 'lid', 'eid', 'intvl', 'remark' );
     my $sql = $site->SQL_LOCK_SELECT_BY_LID;
     my ( $result ) = $dbh->selectrow_hashref( $sql, undef, $lid );
